@@ -20,7 +20,6 @@ class AuthTokenError(Exception):
 class Extractor(object):
 
     def __init__(self, token, config, export, hashtags, since, until, csv, loglevel):
-
         self.token = token
         self.export = export
         self.hashtags = [hashtag.lower() for hashtag in hashtags.replace('#', '').split(',')]
@@ -38,12 +37,13 @@ class Extractor(object):
     async def init(self):
         # create folder to save output
         output_folder = os.path.dirname(self.config.get('MISC', 'output_dir'))
+
         if not os.path.exists(output_folder):
             os.makedirs(output_folder)
 
         if self.loglevel != 'NONE':
             logging.basicConfig(format='%(asctime)s - %(levelname)s - %(message)s',
-                                filename='output/workplace_extractor.log',
+                                filename=f'{self.config.get("MISC", "output_dir")}/workplace_extractor.log',
                                 level=getattr(logging, self.loglevel))
 
         # set the access token to be used in the http calls
@@ -53,15 +53,12 @@ class Extractor(object):
             sys.exit(e)
 
     def extract(self):
-
         loop = asyncio.get_event_loop()
-        loop.run_until_complete(self._extract())
+        return loop.run_until_complete(self._extract())
 
     async def _extract(self):
         await self.init()
 
-        return f'tk {self.token}'
-
         extractor = None
         if self.export == 'POSTS':
             extractor = PostExtractor(extractor=self, since=self.since, until=self.until)
@@ -77,7 +74,7 @@ class Extractor(object):
         logging.info(f'Extraction of posts finished')
 
         if self.export == 'INTERACTIONS':
-            with open('output/workplace_interactions.pickle', 'wb') as handle:
+            with open(f'{self.config.get("MISC", "output_dir")}/workplace_interactions.pickle', 'wb') as handle:
                 pickle.dump(extractor.nodes, handle)
 
             #with open('output/workplace_interactions.pickle', 'rb') as handle:
@@ -93,14 +90,13 @@ class Extractor(object):
         # if a name for the csv file was passed, save the posts in csv format
         if self.csv:
             nodes_pd.replace(to_replace=[r"\\t|\\n|\\r", "\t|\n|\r"], value=[" ", " "], regex=True) \
-                 .to_csv(f'output/{self.csv}', index=False, sep=";")
+                 .to_csv(f'{self.config.get("MISC", "output_dir")}/{self.csv}', index=False, sep=";")
 
         logging.info(f'Post extraction finished')
 
         return nodes_pd
 
     async def set_token(self):
-        print('aqui')
         with open(self.token) as file:
             self.token = file.readline().rstrip()
 
